Struct parquet::decoding::DeltaByteArrayDecoder [−][src]
pub struct DeltaByteArrayDecoder<T: DataType> { /* fields omitted */ }
Delta byte array decoder.
Prefix lengths are encoded using DELTA_BINARY_PACKED encoding, Suffixes are stored
using DELTA_LENGTH_BYTE_ARRAY encoding.
See DeltaByteArrayEncoder for more
information.
Methods
impl<T: DataType> DeltaByteArrayDecoder<T>[src]
impl<T: DataType> DeltaByteArrayDecoder<T>Trait Implementations
impl<'m, T: DataType> Decoder<T> for DeltaByteArrayDecoder<T>[src]
impl<'m, T: DataType> Decoder<T> for DeltaByteArrayDecoder<T>fn set_data(&mut self, _: ByteBufferPtr, _: usize) -> Result<()>[src]
fn set_data(&mut self, _: ByteBufferPtr, _: usize) -> Result<()>Sets the data to decode to be data, which should contain num_values of values to decode. Read more
fn get(&mut self, _: &mut [T::T]) -> Result<usize>[src]
fn get(&mut self, _: &mut [T::T]) -> Result<usize>Consumes values from this decoder and write the results to buffer. This will try to fill up buffer. Read more
fn values_left(&self) -> usize[src]
fn values_left(&self) -> usizeReturns the number of values left in this decoder stream.
fn encoding(&self) -> Encoding[src]
fn encoding(&self) -> EncodingReturns the encoding for this decoder.
impl Decoder<ByteArrayType> for DeltaByteArrayDecoder<ByteArrayType>[src]
impl Decoder<ByteArrayType> for DeltaByteArrayDecoder<ByteArrayType>fn set_data(&mut self, data: ByteBufferPtr, num_values: usize) -> Result<()>[src]
fn set_data(&mut self, data: ByteBufferPtr, num_values: usize) -> Result<()>Sets the data to decode to be data, which should contain num_values of values to decode. Read more
fn get(&mut self, buffer: &mut [ByteArray]) -> Result<usize>[src]
fn get(&mut self, buffer: &mut [ByteArray]) -> Result<usize>Consumes values from this decoder and write the results to buffer. This will try to fill up buffer. Read more
fn values_left(&self) -> usize[src]
fn values_left(&self) -> usizeReturns the number of values left in this decoder stream.
fn encoding(&self) -> Encoding[src]
fn encoding(&self) -> EncodingReturns the encoding for this decoder.