Struct parquet::decoding::PlainDecoder [−][src]
pub struct PlainDecoder<T: DataType> { /* fields omitted */ }
Plain decoding that supports all types.
Values are encoded back to back. For native types, data is encoded as little endian.
Floating point types are encoded in IEEE.
See PlainDecoder for more information.
Methods
impl<T: DataType> PlainDecoder<T>[src]
impl<T: DataType> PlainDecoder<T>Trait Implementations
impl<T: DataType> Decoder<T> for PlainDecoder<T>[src]
impl<T: DataType> Decoder<T> for PlainDecoder<T>fn set_data(&mut self, data: ByteBufferPtr, num_values: usize) -> Result<()>[src]
fn set_data(&mut self, data: ByteBufferPtr, num_values: usize) -> Result<()>Sets the data to decode to be data, which should contain num_values of values to decode. Read more
fn values_left(&self) -> usize[src]
fn values_left(&self) -> usizeReturns the number of values left in this decoder stream.
fn encoding(&self) -> Encoding[src]
fn encoding(&self) -> EncodingReturns the encoding for this decoder.
fn get(&mut self, buffer: &mut [T::T]) -> Result<usize>[src]
fn get(&mut self, buffer: &mut [T::T]) -> Result<usize>Consumes values from this decoder and write the results to buffer. This will try to fill up buffer. Read more
impl Decoder<Int96Type> for PlainDecoder<Int96Type>[src]
impl Decoder<Int96Type> for PlainDecoder<Int96Type>fn get(&mut self, buffer: &mut [Int96]) -> Result<usize>[src]
fn get(&mut self, buffer: &mut [Int96]) -> Result<usize>Consumes values from this decoder and write the results to buffer. This will try to fill up buffer. Read more
fn set_data(&mut self, data: ByteBufferPtr, num_values: usize) -> Result<()>[src]
fn set_data(&mut self, data: ByteBufferPtr, num_values: usize) -> Result<()>Sets the data to decode to be data, which should contain num_values of values to decode. Read more
fn values_left(&self) -> usize[src]
fn values_left(&self) -> usizeReturns the number of values left in this decoder stream.
fn encoding(&self) -> Encoding[src]
fn encoding(&self) -> EncodingReturns the encoding for this decoder.
impl Decoder<BoolType> for PlainDecoder<BoolType>[src]
impl Decoder<BoolType> for PlainDecoder<BoolType>fn set_data(&mut self, data: ByteBufferPtr, num_values: usize) -> Result<()>[src]
fn set_data(&mut self, data: ByteBufferPtr, num_values: usize) -> Result<()>Sets the data to decode to be data, which should contain num_values of values to decode. Read more
fn get(&mut self, buffer: &mut [bool]) -> Result<usize>[src]
fn get(&mut self, buffer: &mut [bool]) -> Result<usize>Consumes values from this decoder and write the results to buffer. This will try to fill up buffer. Read more
fn values_left(&self) -> usize[src]
fn values_left(&self) -> usizeReturns the number of values left in this decoder stream.
fn encoding(&self) -> Encoding[src]
fn encoding(&self) -> EncodingReturns the encoding for this decoder.
impl Decoder<ByteArrayType> for PlainDecoder<ByteArrayType>[src]
impl Decoder<ByteArrayType> for PlainDecoder<ByteArrayType>fn get(&mut self, buffer: &mut [ByteArray]) -> Result<usize>[src]
fn get(&mut self, buffer: &mut [ByteArray]) -> Result<usize>Consumes values from this decoder and write the results to buffer. This will try to fill up buffer. Read more
fn set_data(&mut self, data: ByteBufferPtr, num_values: usize) -> Result<()>[src]
fn set_data(&mut self, data: ByteBufferPtr, num_values: usize) -> Result<()>Sets the data to decode to be data, which should contain num_values of values to decode. Read more
fn values_left(&self) -> usize[src]
fn values_left(&self) -> usizeReturns the number of values left in this decoder stream.
fn encoding(&self) -> Encoding[src]
fn encoding(&self) -> EncodingReturns the encoding for this decoder.
impl Decoder<FixedLenByteArrayType> for PlainDecoder<FixedLenByteArrayType>[src]
impl Decoder<FixedLenByteArrayType> for PlainDecoder<FixedLenByteArrayType>fn get(&mut self, buffer: &mut [ByteArray]) -> Result<usize>[src]
fn get(&mut self, buffer: &mut [ByteArray]) -> Result<usize>Consumes values from this decoder and write the results to buffer. This will try to fill up buffer. Read more
fn set_data(&mut self, data: ByteBufferPtr, num_values: usize) -> Result<()>[src]
fn set_data(&mut self, data: ByteBufferPtr, num_values: usize) -> Result<()>Sets the data to decode to be data, which should contain num_values of values to decode. Read more
fn values_left(&self) -> usize[src]
fn values_left(&self) -> usizeReturns the number of values left in this decoder stream.
fn encoding(&self) -> Encoding[src]
fn encoding(&self) -> EncodingReturns the encoding for this decoder.